@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : DarkIce.cpp
-   Version  : $Revision: 1.45 $
+   Version  : $Revision: 1.49 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
    
@@ -84,6 +84,10 @@
 #include "LameLibEncoder.h"
 #endif
 
+#ifdef HAVE_TWOLAME_LIB
+#include "TwoLameLibEncoder.h"
+#endif
+
 #ifdef HAVE_VORBIS_LIB
 #include "VorbisLibEncoder.h"
 #endif
@@ -101,7 +105,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: DarkIce.cpp,v 1.45 2005/10/22 10:34:21 darkeye Exp $";
+static const char fileid[] = "$Id: DarkIce.cpp,v 1.49 2006/03/23 09:34:57 darkeye Exp $";
 
 
 /*------------------------------------------------------------------------------
@@ -144,13 +148,21 @@ DarkIce :: init ( const Config      & config )              throw ( Exception )
     duration = Util::strToL( str);
     str = cs->getForSure( "bufferSecs", " missing in section [general]");
     bufferSecs = Util::strToL( str);
+    if (bufferSecs == 0) {
+        throw Exception(__FILE__, __LINE__,
+                        "setting bufferSecs to 0 not supported");
+    }
     str           = cs->get( "reconnect");
     reconnect     = str ? (Util::strEq( str, "yes") ? true : false) : true;
 
+    // real-time scheduling is enabled by default
+    str = cs->get( "realtime" );
+    enableRealTime = str ? (Util::strEq( str, "yes") ? true : false) : true;
+
 
     // the [input] section
     if ( !(cs = config.get( "input")) ) {
-        throw Exception( __FILE__, __LINE__, "no section [general] in config");
+        throw Exception( __FILE__, __LINE__, "no section [input] in config");
     }
     
     str        = cs->getForSure( "sampleRate", " missing in section [input]");
@@ -199,9 +211,9 @@ DarkIce :: configIceCast (  const Config      & config,
             break;
         }
 
-#ifndef HAVE_LAME_LIB
+#if !defined HAVE_LAME_LIB && !defined HAVE_TWOLAME_LIB
         throw Exception( __FILE__, __LINE__,
-                         "DarkIce not compiled with lame support, "
+                         "DarkIce not compiled with lame or twolame support, "
                          "thus can't connect to IceCast 1.x, stream: ",
                          stream);
 #else
@@ -271,6 +283,8 @@ DarkIce :: configIceCast (  const Config      & config,
             throw Exception( __FILE__, __LINE__,
                              "invalid bitrate mode: ", str);
         }
+        
+        
 
         server      = cs->getForSure( "server", " missing in section ", stream);
         str         = cs->getForSure( "port", " missing in section ", stream);
@@ -330,18 +344,41 @@ DarkIce :: configIceCast (  const Config      & config,
                                            localDumpFile,
                                            bufferSecs );
 
-        audioOuts[u].encoder = new LameLibEncoder( audioOuts[u].server.get(),
-                                                   dsp.get(),
-                                                   bitrateMode,
-                                                   bitrate,
-                                                   quality,
-                                                   sampleRate,
-                                                   channel,
-                                                   lowpass,
-                                                   highpass );
+        str = cs->getForSure( "format", " missing in section ", stream);
+
+        if (!Util::strEq(str, "mp3") && !Util::strEq(str, "mp2")) {
+            throw Exception( __FILE__, __LINE__,
+                             "unsupported stream format: ", str);
+
+        }
+
+#ifdef HAVE_LAME_LIB
+        if ( Util::strEq( str, "mp3") ) {
+			audioOuts[u].encoder = new LameLibEncoder( audioOuts[u].server.get(),
+													   dsp.get(),
+													   bitrateMode,
+													   bitrate,
+													   quality,
+													   sampleRate,
+													   channel,
+													   lowpass,
+													   highpass );
+        }
+#endif
+#ifdef HAVE_TWOLAME_LIB
+        if ( Util::strEq( str, "mp2") ) {
+			audioOuts[u].encoder = new TwoLameLibEncoder(
+                                                      audioOuts[u].server.get(),
+													  dsp.get(),
+													  bitrateMode,
+													  bitrate,
+													  sampleRate,
+													  channel );
+        }
+#endif
 
         encConnector->attach( audioOuts[u].encoder.get());
-#endif // HAVE_LAME_LIB
+#endif // HAVE_LAME_LIB || HAVE_TWOLAME_LIB
     }
 
     noAudioOuts += u;
@@ -401,6 +438,8 @@ DarkIce :: configIceCast2 (  const Config      & config,
             format = IceCast2::oggVorbis;
         } else if ( Util::strEq( str, "mp3") ) {
             format = IceCast2::mp3;
+        } else if ( Util::strEq( str, "mp2") ) {
+            format = IceCast2::mp2;
         } else if ( Util::strEq( str, "aac") ) {
             format = IceCast2::aac;
         } else {
@@ -529,6 +568,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
 #endif // HAVE_LAME_LIB
                 break;
 
+
             case IceCast2::oggVorbis:
 #ifndef HAVE_VORBIS_LIB
                 throw Exception( __FILE__, __LINE__,
@@ -548,6 +588,24 @@ DarkIce :: configIceCast2 (  const Config      & config,
 #endif // HAVE_VORBIS_LIB
                 break;
 
+            case IceCast2::mp2:
+#ifndef HAVE_TWOLAME_LIB
+                throw Exception( __FILE__, __LINE__,
+                                 "DarkIce not compiled with TwoLame support, "
+                                 "thus can't create mp2 stream: ",
+                                 stream);
+#else
+                audioOuts[u].encoder = new TwoLameLibEncoder(
+                                                    audioOuts[u].server.get(),
+                                                    dsp.get(),
+                                                    bitrateMode,
+                                                    bitrate,
+                                                    sampleRate,
+                                                    channel );
+#endif // HAVE_TWOLAME_LIB
+                break;
+
+
             case IceCast2::aac:
 #ifndef HAVE_FAAC_LIB
                 throw Exception( __FILE__, __LINE__,
@@ -787,6 +845,7 @@ DarkIce :: configFileCast (  const Config      & config )
         format      = cs->getForSure( "format", " missing in section ", stream);
         if ( !Util::strEq( format, "vorbis")
           && !Util::strEq( format, "mp3")
+          && !Util::strEq( format, "mp2")
           && !Util::strEq( format, "aac") ) {
             throw Exception( __FILE__, __LINE__,
                              "unsupported stream format: ", format);
@@ -815,10 +874,6 @@ DarkIce :: configFileCast (  const Config      & config )
                 throw Exception( __FILE__, __LINE__,
                                  "bitrate not specified for CBR encoding");
             }
-            if ( cs->get( "quality" ) == 0 ) {
-                throw Exception( __FILE__, __LINE__,
-                                 "quality not specified for CBR encoding");
-            }
         } else if ( Util::strEq( str, "abr") ) {
             bitrateMode = AudioEncoder::abr;
 
@@ -881,7 +936,22 @@ DarkIce :: configFileCast (  const Config      & config )
                                                     dsp->getChannel(),
                                                     lowpass,
                                                     highpass );
-#endif // HAVE_LAME_LIB
+#endif // HAVE_TWOLAME_LIB
+        } else if ( Util::strEq( format, "mp2") ) {
+#ifndef HAVE_TWOLAME_LIB
+                throw Exception( __FILE__, __LINE__,
+                                "DarkIce not compiled with TwoLAME support, "
+                                "thus can't create MPEG Audio Layer 2 stream: ",
+                                stream);
+#else
+                audioOuts[u].encoder = new TwoLameLibEncoder(
+                                                    audioOuts[u].server.get(),
+                                                    dsp.get(),
+                                                    bitrateMode,
+                                                    bitrate,
+                                                    sampleRate,
+                                                    dsp->getChannel() );
+#endif // HAVE_TWOLAME_LIB
         } else if ( Util::strEq( format, "vorbis") ) {
 #ifndef HAVE_VORBIS_LIB
                 throw Exception( __FILE__, __LINE__,
@@ -894,7 +964,6 @@ DarkIce :: configFileCast (  const Config      & config )
                                                     dsp.get(),
                                                     bitrateMode,
                                                     bitrate,
-                                                    quality,
                                                     dsp->getSampleRate(),
                                                     dsp->getChannel() );
 #endif // HAVE_VORBIS_LIB
@@ -1053,9 +1122,14 @@ int
 DarkIce :: run ( void )                             throw ( Exception )
 {
     reportEvent( 3, "encoding");
-    setRealTimeScheduling();
+    
+    if (enableRealTime) {
+        setRealTimeScheduling();
+    }
     encode();
-    setOriginalScheduling();
+    if (enableRealTime) {
+        setOriginalScheduling();
+    }
     reportEvent( 3, "encoding ends");
 
     return 0;
@@ -1067,6 +1141,18 @@ DarkIce :: run ( void )                             throw ( Exception )
   $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
 
   $Log: DarkIce.cpp,v $
+  Revision 1.49  2006/03/23 09:34:57  darkeye
+  fixed checking for mp3 and mp2 lib support for icecast-1.x streams
+
+  Revision 1.48  2006/01/27 15:02:05  darkeye
+  fixued issue of compiling without lame, but with twolame
+
+  Revision 1.47  2006/01/25 22:47:15  darkeye
+  added mpeg2 support, thanks to Nicholas J Humfrey
+
+  Revision 1.46  2006/01/19 16:09:05  darkeye
+  added check for bufferSecs setting not to be 0
+
   Revision 1.45  2005/10/22 10:34:21  darkeye
   added highpass and lowpass values to icecast2 sections
 
