@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : DarkIce.h
-   Version  : $Revision: 1.15 $
+   Version  : $Revision: 1.16 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/DarkIce.h,v $
    
@@ -73,7 +73,7 @@
  *  Program main object.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.15 $
+ *  @version $Revision: 1.16 $
  */
 class DarkIce : public virtual Referable, public virtual Reporter
 {
@@ -119,6 +119,11 @@ class DarkIce : public virtual Referable, public virtual Reporter
          */
         Ref<Connector>          encConnector;
 
+        /**
+         *  Should we turn real-time scheduling on ?
+         */
+        int                     enableRealTime;
+
         /**
          *  Original scheduling policy
          */
@@ -309,6 +314,9 @@ class DarkIce : public virtual Referable, public virtual Reporter
   $Source: /cvsroot/darkice/darkice/src/DarkIce.h,v $
 
   $Log: DarkIce.h,v $
+  Revision 1.16  2006/01/25 22:47:15  darkeye
+  added mpeg2 support, thanks to Nicholas J Humfrey
+
   Revision 1.15  2005/04/04 08:36:17  darkeye
   commited changes to enable Jack support
   thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
