@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : IceCast2.cpp
-   Version  : $Revision: 1.12 $
+   Version  : $Revision: 1.13 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/IceCast2.cpp,v $
    
@@ -67,7 +67,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: IceCast2.cpp,v 1.12 2005/04/16 21:57:34 darkeye Exp $";
+static const char fileid[] = "$Id: IceCast2.cpp,v 1.13 2006/01/25 22:47:15 darkeye Exp $";
 
 
 /*------------------------------------------------------------------------------
@@ -149,6 +149,7 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
     sink->write( str, strlen( str));
     switch ( format ) {
         case mp3:
+        case mp2:
             str = "audio/mpeg";
             break;
 
@@ -259,6 +260,9 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
   $Source: /cvsroot/darkice/darkice/src/IceCast2.cpp,v $
 
   $Log: IceCast2.cpp,v $
+  Revision 1.13  2006/01/25 22:47:15  darkeye
+  added mpeg2 support, thanks to Nicholas J Humfrey
+
   Revision 1.12  2005/04/16 21:57:34  darkeye
   added AAC support through the faac codec, http://www.audiocoding.com/
 
