@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : IceCast2.h
-   Version  : $Revision: 1.5 $
+   Version  : $Revision: 1.6 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/IceCast2.h,v $
    
@@ -54,7 +54,7 @@
  *  ice login
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.5 $
+ *  @version $Revision: 1.6 $
  */
 class IceCast2 : public CastSink
 {
@@ -63,7 +63,7 @@ class IceCast2 : public CastSink
         /**
          *  Type for specifying the format of the stream.
          */
-       enum StreamFormat { mp3, oggVorbis, aac };
+       enum StreamFormat { mp3, mp2, oggVorbis, aac };
 
 
     private:
@@ -273,6 +273,9 @@ class IceCast2 : public CastSink
   $Source: /cvsroot/darkice/darkice/src/IceCast2.h,v $
 
   $Log: IceCast2.h,v $
+  Revision 1.6  2006/01/25 22:47:15  darkeye
+  added mpeg2 support, thanks to Nicholas J Humfrey
+
   Revision 1.5  2005/04/16 21:57:34  darkeye
   added AAC support through the faac codec, http://www.audiocoding.com/
 
