@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : LameLibEncoder.cpp
-   Version  : $Revision: 1.19 $
-   Author   : $Author: jbebel $
+   Version  : $Revision: 1.20 $
+   Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/LameLibEncoder.cpp,v $
    
    Copyright notice:
@@ -51,7 +51,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: LameLibEncoder.cpp,v 1.19 2005/04/13 19:04:55 jbebel Exp $";
+static const char fileid[] = "$Id: LameLibEncoder.cpp,v 1.20 2006/01/25 22:47:15 darkeye Exp $";
 
 
 /* ===============================================  local function prototypes */
@@ -260,8 +260,10 @@ LameLibEncoder :: open ( void )
                          "lame lib initializing params error" );
     }
 
-    lame_print_config( lameGlobalFlags);
-
+	if (getReportVerbosity() >= 3) {
+ 	   lame_print_config( lameGlobalFlags);
+	}
+	
     return true;
 }
 
@@ -396,6 +398,9 @@ LameLibEncoder :: close ( void )                    throw ( Exception )
   $Source: /cvsroot/darkice/darkice/src/LameLibEncoder.cpp,v $
 
   $Log: LameLibEncoder.cpp,v $
+  Revision 1.20  2006/01/25 22:47:15  darkeye
+  added mpeg2 support, thanks to Nicholas J Humfrey
+
   Revision 1.19  2005/04/13 19:04:55  jbebel
   Distribute lame qualities better, and prevent values greater than 9 which are invalid.
 
