@@ -5,8 +5,8 @@
    Tyrell DarkIce
 
    File     : MultiThreadedConnector.cpp
-   Version  : $Revision: 1.6 $
-   Author   : $Author: jbebel $
+   Version  : $Revision: 1.8 $
+   Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/MultiThreadedConnector.cpp,v $
    
    Copyright notice:
@@ -52,7 +52,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: MultiThreadedConnector.cpp,v 1.6 2005/04/13 22:03:32 jbebel Exp $";
+static const char fileid[] = "$Id: MultiThreadedConnector.cpp,v 1.8 2006/05/18 07:13:00 darkeye Exp $";
 
 
 /* ===============================================  local function prototypes */
@@ -315,10 +315,15 @@ MultiThreadedConnector :: sinkThread( int       ixSink )
 
         if ( !threadData->accepting ) {
             if ( reconnect ) {
+                reportEvent( 4,
+                           "MultiThreadedConnector :: sinkThread reconnecting ",
+                            ixSink);
                 // if we're not accepting, try to reopen the sink
                 try {
                     sink->close();
+                    sched_yield();
                     sink->open();
+                    sched_yield();
                     threadData->accepting = sink->isOpen();
                 } catch ( Exception   & e ) {
                     // don't care, just try and try again
@@ -369,26 +374,30 @@ MultiThreadedConnector :: ThreadData :: threadFunction( void  * param )
     
     pthread_getschedparam( threadData->thread, &sched_type, &sched );
 
-    reportEvent( 5, "MultiThreadedConnector :: ThreadData :: threadFunction, was (thread, priority, type): ",
-        param,
-	sched.sched_priority,
-        sched_type == SCHED_FIFO ? "SCHED_FIFO" :
-            sched_type == SCHED_RR ? "SCHED_RR" :
-            sched_type == SCHED_OTHER ? "SCHED_OTHER" :
-            "INVALID"
+    reportEvent( 5,
+                 "MultiThreadedConnector :: ThreadData :: threadFunction, "
+                 "was (thread, priority, type): ",
+                 param,
+	             sched.sched_priority,
+                 sched_type == SCHED_FIFO ? "SCHED_FIFO" :
+                    sched_type == SCHED_RR ? "SCHED_RR" :
+                    sched_type == SCHED_OTHER ? "SCHED_OTHER" :
+                    "INVALID"
     );
 
     sched.sched_priority = 1;
     pthread_setschedparam( threadData->thread, SCHED_FIFO, &sched);
 
     pthread_getschedparam( threadData->thread, &sched_type, &sched );
-    reportEvent( 5, "MultiThreadedConnector :: ThreadData :: threadFunction, now is (thread, priority, type): ",
-        param,
-	sched.sched_priority,
-        sched_type == SCHED_FIFO ? "SCHED_FIFO" :
-            sched_type == SCHED_RR ? "SCHED_RR" :
-            sched_type == SCHED_OTHER ? "SCHED_OTHER" :
-            "INVALID"
+    reportEvent( 5,
+                 "MultiThreadedConnector :: ThreadData :: threadFunction, "
+                 "now is (thread, priority, type): ",
+                 param,
+	             sched.sched_priority,
+                 sched_type == SCHED_FIFO ? "SCHED_FIFO" :
+                    sched_type == SCHED_RR ? "SCHED_RR" :
+                    sched_type == SCHED_OTHER ? "SCHED_OTHER" :
+                    "INVALID"
     );
 
     threadData->connector->sinkThread( threadData->ixSink);
@@ -402,6 +411,12 @@ MultiThreadedConnector :: ThreadData :: threadFunction( void  * param )
   $Source: /cvsroot/darkice/darkice/src/MultiThreadedConnector.cpp,v $
 
   $Log: MultiThreadedConnector.cpp,v $
+  Revision 1.8  2006/05/18 07:13:00  darkeye
+  cosmetic changes
+
+  Revision 1.7  2006/05/16 09:00:08  darkeye
+  added yield calls to the connector, when trying to reconnect...
+
   Revision 1.6  2005/04/13 22:03:32  jbebel
   Set priority explicitly for encoding threads.  This needs more testing.
 
