@@ -5,7 +5,7 @@
    Tyrell DarkIce
 
    File     : ShoutCast.h
-   Version  : $Revision: 1.2 $
+   Version  : $Revision: 1.3 $
    Author   : $Author: darkeye $
    Location : $Source: /cvsroot/darkice/darkice/src/ShoutCast.h,v $
    
@@ -54,7 +54,7 @@
  *  icy login
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.2 $
+ *  @version $Revision: 1.3 $
  */
 class ShoutCast : public CastSink
 {
@@ -136,6 +136,8 @@ class ShoutCast : public CastSink
          *  @param irc IRC info string for the stream.
          *  @param aim AIM info string for the stream.
          *  @param icq ICQ info string for the stream.
+         *  @param streamDump an optional sink to dump the binary stream
+         *                    data to.
          *  @param bufferDuration duration of the BufferedSink buffer
          *                        in seconds.
          *  @exception Exception
@@ -259,6 +261,9 @@ class ShoutCast : public CastSink
   $Source: /cvsroot/darkice/darkice/src/ShoutCast.h,v $
 
   $Log: ShoutCast.h,v $
+  Revision 1.3  2005/04/14 11:53:17  darkeye
+  fixed API documentation issues
+
   Revision 1.2  2002/02/20 11:54:11  darkeye
   added local dump file possibility
 
